mafw.examples.loop\_modifier
============================

.. automodule:: mafw.examples.loop_modifier

   
   .. rubric:: Functions

   .. autosummary::
   
      is_prime
   
   .. rubric:: Classes

   .. autosummary::
   
      FindNPrimeNumber
      FindPrimeNumberInRange
      ModifyLoopProcessor
   